@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10109 2017-07-20 07:53:14Z David $
+# $Id: __init__.py 10176 2017-08-13 09:12:03Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-07-20 15:53:14 +0800 (Thu, 20 Jul 2017) $
-# $Revision: 10109 $
+# $Date: 2017-08-13 17:12:03 +0800 (Sun, 13 Aug 2017) $
+# $Revision: 10176 $
 
 import os
 import sys
@@ -189,3 +189,20 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     if 'ACCOUNT_LOGIN_REDIRECT_URL' not in settingsDict:
         settingsDict['ACCOUNT_LOGIN_REDIRECT_URL'] = settingsDict[
                                                      'LOGIN_REDIRECT_URL']
+
+    #=========================================================================
+    # django user accounts http protocal settings.
+    # see details in account/models.py EmailConfirmation >> send()
+    # reference: https://docs.djangoproject.com/en/1.8/ref/
+    # settings/#secure-proxy-ssl-header
+
+
+    if 'SECURE_PROXY_SSL_HEADER' not in settingsDict:
+        https = os.environ.get('HTTPS', None)
+        if https == 'on':
+            settingsDict['SECURE_PROXY_SSL_HEADER'] = (
+                'HTTP_X_FORWARDED_PROTO', 'https')
+
+    if 'SECURE_PROXY_SSL_HEADER' in settingsDict:
+        settingsDict['DEFAULT_HTTP_PROTOCOL'] = settingsDict[
+                                                   'SECURE_PROXY_SSL_HEADER'][1]
\ No newline at end of file
