@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 10121 2017-07-25 08:18:08Z David $
+# $Id: AttachSettingsTest.py 10176 2017-08-13 09:12:03Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-07-25 16:18:08 +0800 (Tue, 25 Jul 2017) $
-# $Revision: 10121 $
+# $Date: 2017-08-13 17:12:03 +0800 (Sun, 13 Aug 2017) $
+# $Revision: 10176 $
 
 import os
 
@@ -75,10 +75,54 @@ class TestAttachSettings(TestCase):
                     'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
                 }
             },
-            'LOGIN_REDIRECT_URL': '/settings',    
+            'LOGIN_REDIRECT_URL': '/settings',
         }
         
+        settingsContentForHTTP = {'AUTHENTICATION_BACKENDS' : (
+            ),
+            'INSTALLED_APPS' : (
+                'django.contrib.admin',
+                'django.contrib.auth',
+                'django.contrib.contenttypes',
+                'django.contrib.sessions',
+                'django.contrib.messages',
+                'django.contrib.staticfiles',
+            ),
+            'MIDDLEWARE_CLASSES' : (
+                'django.contrib.sessions.middleware.SessionMiddleware',
+                'django.middleware.common.CommonMiddleware',
+                'django.middleware.csrf.CsrfViewMiddleware',
+                'django.contrib.auth.middleware.AuthenticationMiddleware',
+                ('django.contrib.auth.middleware.'
+                 'SessionAuthenticationMiddleware'),
+                'django.contrib.messages.middleware.MessageMiddleware',
+                'django.middleware.clickjacking.XFrameOptionsMiddleware',
+                'django.middleware.security.SecurityMiddleware',
+            ),
+            'TEMPLATES' : [
+                {
+                    'BACKEND': ('django.template.backends.django.'
+                                'DjangoTemplates'),
+                    'DIRS': [],
+                    'APP_DIRS': True,
+                    'OPTIONS': {
+                        'context_processors': [
+                            'django.template.context_processors.debug',
+                            'django.template.context_processors.request',
+                            'django.contrib.auth.context_processors.auth',
+                            ('django.contrib.messages.context_processors.'
+                             'messages'),
+                        ],
+                    },
+                },
+            ],
+            'SECURE_PROXY_SSL_HEADER': ('HTTP_X_FORWARDED_PROTO', 'http')
+        }
+
+
+        os.environ["HTTPS"] = "on"
         member.attachSettings(settingsContent)
+        member.attachSettings(settingsContentForHTTP)
         
         templatesSettings = {
             'TEMPLATES' : [
@@ -104,7 +148,7 @@ class TestAttachSettings(TestCase):
                 },
             ],
         }
-
+        
         loginUrlSettings = {
             'LOGIN_URL': '/accounts/login/',
             'LOGIN_REDIRECT_URL': '/settings',
@@ -115,6 +159,16 @@ class TestAttachSettings(TestCase):
             'ACCOUNT_LOGIN_URL': '/accounts/login/',
             'ACCOUNT_LOGIN_REDIRECT_URL': '/settings',
         }
+
+        httpSettings = {
+            'SECURE_PROXY_SSL_HEADER': ('HTTP_X_FORWARDED_PROTO', 'http'),
+            'DEFAULT_HTTP_PROTOCOL': 'http'
+        }
+
+        httpsSettings = {
+            'SECURE_PROXY_SSL_HEADER': ('HTTP_X_FORWARDED_PROTO', 'https'),
+            'DEFAULT_HTTP_PROTOCOL': 'https'
+        }
         
         self.assertEqual(settingsContent['TEMPLATES'],
                          templatesSettings['TEMPLATES'])
@@ -129,4 +183,16 @@ class TestAttachSettings(TestCase):
                          loginUrlSettings['SOCIAL_AUTH_LOGIN_REDIRECT_URL'])
         
         self.assertEqual(settingsContent['ACCOUNT_LOGIN_REDIRECT_URL'], 
-                         loginUrlSettings['SOCIAL_AUTH_LOGIN_REDIRECT_URL'])
\ No newline at end of file
+                         loginUrlSettings['SOCIAL_AUTH_LOGIN_REDIRECT_URL'])
+
+        self.assertEqual(settingsContent['SECURE_PROXY_SSL_HEADER'],
+                         httpsSettings['SECURE_PROXY_SSL_HEADER'])
+
+        self.assertEqual(settingsContentForHTTP['SECURE_PROXY_SSL_HEADER'],
+                         httpSettings['SECURE_PROXY_SSL_HEADER'])
+
+        self.assertEqual(settingsContent['DEFAULT_HTTP_PROTOCOL'],
+                         httpsSettings['DEFAULT_HTTP_PROTOCOL'])
+
+        self.assertEqual(settingsContentForHTTP['DEFAULT_HTTP_PROTOCOL'],
+                         httpSettings['DEFAULT_HTTP_PROTOCOL'])
